import UIKit
import PlaygroundSupport

/**
Klasse zur Beschreibung eines Handballspiels

- author: Klaus Reinold
- version 0.4
*/
class Handballspiel
{
    /** Termin des Spiels */
    private var termin: String
    /** Liga */
    private var liga: String
    /** Spielort */
    private var spielort: String
    /** Mannschaft 1 */
    private var mannschaft1: String
    /** Mannschaft 2 */
    private var mannschaft2: String
    /** Schiedsrichter1 */
    private var schiedsrichter1: String
    /** Schiedsrichter2 */
    private var schiedsrichter2: String
    /** Zeitnehmer */
    private var zeitnehmer: String
    /** Sekretär */
    private var sekretär: String
    /** Offizielle der Mannschaft 1 (Trainer usw.) */
    private var offizielleMannschaft1: [String]
    /** Offizielle der Mannschaft 2 (Trainer usw.) */
    private var offizielleMannschaft2: [String]
    /** Spieler der Mannschaft 1 */
    private var spielerMannschaft1: [String]
    /** Spieler der Mannschaft 2 */
    private var spielerMannschaft2: [String]
    /** Feld der Minuten, in denen ein Tor für Mannschaft 1 geschossen wurde */
    private var torMinuteMannschaft1: [Int]
    /** Feld der Spieler, die ein Tor für Mannschaft 1 geschossen haben */
    private var torSpielerMannschaft1: [String]
    /** Feld der Minuten, in denen ein Tor für Mannschaft 2 geschossen wurde */
    private var torMinuteMannschaft2: [Int]
    /** Feld der Spieler, die ein Tor für Mannschaft 1 geschossen haben */
    private var torSpielerMannschaft2: [String]
    /** Feld der Minuten der Siebenmeter, die für Mannschaft 1 geschossen wurden */
    private var siebenmeterMinuteMannschaft1: [Int]
    /** Feld der Spieler, die für Mannschaft 1 einen Siebenmeter geschossen haben */
    private var siebenmeterSpielerMannschaft1: [String]
    /** Feld speichert, ob Siebenmeter für Mannschaft 1 ein Treffer war */
    private var istSiebenmeterTrefferMannschaft1: [Bool]
    /** Feld der Minuten der Siebenmeter, die für Mannschaft 2 geschossen wurden */
    private var siebenmeterMinuteMannschaft2: [Int]
    /** Feld der Spieler, die für Mannschaft 2 einen Siebenmeter geschossen haben */
    private var siebenmeterSpielerMannschaft2: [String]
    /** Feld speichert, ob Siebenmeter für Mannschaft 2 ein Treffer war */
    private var istSiebenmeterTrefferMannschaft2: [Bool]
    /** Zweiminutenstrafe x in Minute y für Mannschaft1 */
    private var zweiMinStrafeMinuteMannschaft1: [Int]
    /** Zweiminutenstrafe x für Spieler y für Mannschaft1 */
    private var zweiMinStrafeSpielerMannschaft1: [String]
    /** Zweiminutenstrafe x in Minute y für Mannschaft2 */
    private var zweiMinStrafeMinuteMannschaft2: [Int]
    /** Zweiminutenstrafe x für Spieler y für Mannschaft2 */
    private var zweiMinStrafeSpielerMannschaft2: [String]
    /** Auszeit1 von Mannschaft1 */
    private var timeout1Mannschaft1: Int
    /** Auszeit2 von Mannschaft1 */
    private var timeout2Mannschaft1: Int
    /** Auszeit1 von Mannschaft2 */
    private var timeout1Mannschaft2: Int
    /** Auszeit2 von Mannschaft2 */
    private var timeout2Mannschaft2: Int

    /**
	Konstruktor für Objekte der Klasse Handballspiel
	- parameters:
		- terminNeu: Spieltermin
		- ligaNeu: Liga des Spiels
		- spielortNeu: Ort des Spiels
		- mannschaft1Neu: erste Mannschaft
		- mannschaft2Neu: zweite Mannschaft
    */
    init(terminNeu: String, ligaNeu: String, spielortNeu: String, mannschaft1Neu: String,  mannschaft2Neu: String)
    {
        termin = terminNeu
        liga = ligaNeu
        spielort = spielortNeu
        mannschaft1 = mannschaft1Neu
        mannschaft2 = mannschaft2Neu
		schiedsrichter1 = ""
		schiedsrichter2 = ""
    	zeitnehmer = ""
		sekretär = ""
        offizielleMannschaft1 = [String]()
        offizielleMannschaft2 = [String]()
        spielerMannschaft1 = [String]()
        spielerMannschaft2 = [String]()
        torMinuteMannschaft1 = [Int]()
        torSpielerMannschaft1 = [String]()
        torMinuteMannschaft2 = [Int]()
        torSpielerMannschaft2 = [String]()
        siebenmeterMinuteMannschaft1 = [Int]()
        siebenmeterSpielerMannschaft1 = [String]()
        istSiebenmeterTrefferMannschaft1 = [Bool]()
        siebenmeterMinuteMannschaft2 = [Int]()
        siebenmeterSpielerMannschaft2 = [String]()
        istSiebenmeterTrefferMannschaft2 = [Bool]()
        zweiMinStrafeMinuteMannschaft1 = [Int]()
        zweiMinStrafeSpielerMannschaft1 = [String]()
        zweiMinStrafeMinuteMannschaft2 = [Int]()
        zweiMinStrafeSpielerMannschaft2 = [String]()
        timeout1Mannschaft1 = 0
        timeout2Mannschaft1 = 0
        timeout1Mannschaft2 = 0
        timeout2Mannschaft2 = 0
    }

    /**
	Festlegen eines der vier Schiedsrichter
	- parameters:
		- name: Name des Schiedsrichters
		- art: mögliche Arten: Schiedsrichter 1, Schiedsrichter 2, Zeitnehmer, Sekretär
    */
    func SchiedsrichterFestlegen(nameNeu: String, artNeu: String)
    {
        switch artNeu
        {
            case "Schiedsrichter 1":
                schiedsrichter1 = nameNeu;
            case "Schiedsrichter 2":
                schiedsrichter2 = nameNeu;
            case "Zeitnehmer":
                zeitnehmer = nameNeu;
            case "Sekretär":
                sekretär = nameNeu;
            default: print("Ungültige Angabe bei Art des Schiedsrichters. Zulässig: Schiedsrichter 1, Schiedsrichter 2, Zeitnehmer, Sekretär")
        }
    }

    /**
	Festlegen eines Offiziellen (Trainer etc.) für eine Mannschaft
	- parameters:
		- mannschaftNeu: Name der Mannschaft
		- offiziellerNeu: Name des Offiziellen
    */
    func OffiziellenFestlegenFürMannschaft(mannschaftNeu: String, offiziellerNeu: String)
    {
        if mannschaft1 == mannschaftNeu
        {
            offizielleMannschaft1.append(offiziellerNeu)
        }
        else
        {
            if mannschaft2 == mannschaftNeu
            {
                offizielleMannschaft2.append(offiziellerNeu)
            }
            else
            {
                print("Mannschaft nicht erkannt")
            }
        }
    }

    /**
	Festlegen eines Spielers für eine Mannschaft
	- parameters:
		- mannschaftNeu: Name der Mannschaft
		- spielerNeu: Name des Spielers
    */
    func SpielerFestlegenFürMannschaft(mannschaftNeu: String, spielerNeu: String)
    {
        if mannschaft1 == mannschaftNeu
        {
            spielerMannschaft1.append(spielerNeu)
        }
        else
        {
            if mannschaft2 == mannschaftNeu
            {
                spielerMannschaft2.append(spielerNeu)
            }
            else
            {
                print("Mannschaft nicht erkannt")
            }
        }
    }

    /**
	Festlegen eines Tores für eine Mannschaft
	- parameters:
		- mannschaftNeu: Name der Mannschaft
		- spielerNeu: Name des Spielers
		- minuteNeu: Minute des Tores
    */
    func TorFestlegenFürMannschaft(mannschaftNeu: String, spielerNeu: String, minuteNeu: Int)
    {
        if mannschaft1 == mannschaftNeu
        {
            torSpielerMannschaft1.append(spielerNeu)
            torMinuteMannschaft1.append(minuteNeu)
        }
        else
        {
            if mannschaft2 == mannschaftNeu
            {
                torSpielerMannschaft2.append(spielerNeu)
                torMinuteMannschaft2.append(minuteNeu)
            }
            else
            {
                print("Mannschaft nicht erkannt")
            }
        }
    }

    /**
	Festlegen eines Siebenmeters für eine Mannschaft
	- parameters:
		- mannschaftNeu: Name der Mannschaft
		- spielerNeu: Name des Spielers
		- minuteNeu: Minute des Tores
    */
    func SiebenmeterFestlegenFürMannschaft(mannschaftNeu: String, spielerNeu: String, minuteNeu: Int, istTreffer: Bool)
    {
        if mannschaft1 == mannschaftNeu
        {
            siebenmeterSpielerMannschaft1.append(spielerNeu)
            siebenmeterMinuteMannschaft1.append(minuteNeu)
            istSiebenmeterTrefferMannschaft1.append(istTreffer)
        }
        else
        {
            if mannschaft2 == mannschaftNeu
            {
                siebenmeterSpielerMannschaft1.append(spielerNeu)
                siebenmeterMinuteMannschaft1.append(minuteNeu)
                istSiebenmeterTrefferMannschaft1.append(istTreffer)
            }
            else
            {
                print("Mannschaft nicht erkannt")
            }
        }
    }

    /**
	Festlegen einer Zweiminutenstrafe für eine Mannschaft
	- parameters:
		- mannschaftNeu: Name der Mannschaft
		- spielerNeu: Name des Spielers
		- minuteNeu: Minute der Strafe
    */
    func ZweiminutenstrafeFestlegenFürMannschaft(mannschaftNeu: String, spielerNeu: String, minuteNeu: Int)
    {
        if mannschaft1 == mannschaftNeu
        {
            zweiMinStrafeSpielerMannschaft1.append(spielerNeu)
            zweiMinStrafeMinuteMannschaft1.append(minuteNeu)
        }
        else
        {
            if mannschaft2 == mannschaftNeu
            {
                zweiMinStrafeSpielerMannschaft2.append(spielerNeu)
                zweiMinStrafeMinuteMannschaft2.append(minuteNeu)
            }
            else
            {
                print("Mannschaft nicht erkannt")
            }
        }
    }

    /**
	Festlegen eines Timeouts für eine Mannschaft
	- parameters:
		- mannschaftNeu: Name der Mannschaft
		- halbzeitNeu: aktuelle Halbzeit
		- minuteNeu: Minute des Timeouts
    */
    func TimeoutSetzen(mannschaftNeu: String, halbzeitNeu: Int, minuteNeu: Int)
    {
        if mannschaft1 == mannschaftNeu
        {
            if halbzeitNeu == 1
            {
                timeout1Mannschaft1 = minuteNeu
            }
            else
            {
                timeout2Mannschaft1 = minuteNeu
            }
        }
        else
        {
            if mannschaft2 == mannschaftNeu
            {
                if halbzeitNeu == 1
                {
                    timeout1Mannschaft2 = minuteNeu
                }
                else
                {
                    timeout2Mannschaft2 = minuteNeu
                }
            }
            else
            {
                print("Mannschaft nicht erkannt")
            }
        }
    }
}
